@@ -950,9 +950,21 @@ class HighlightAreaRect : public RegularAreaRect
 public:
     /**
      * Creates a new highlight area rect with the coordinates of
-     * the given @p area.
+     * the given @p area, @p color and @p search_id.
+     *
+     * @since 25.12
      */
-    explicit HighlightAreaRect(const RegularAreaRect *area = nullptr);
+    explicit HighlightAreaRect(const RegularAreaRect &area, const QColor &color, int search_id = INVALID_SEARCH_ID);
+
+    /**
+     * Creates a new highlight area rect with the coordinates of
+     * the given @p area.
+     *
+     * @deprecated use HighlightAreaRect(const RegularAreaRect &area, const QColor &color, int id)
+     */
+    OKULARCORE_DEPRECATED explicit HighlightAreaRect(const RegularAreaRect *area = nullptr);
+
+    static constexpr int INVALID_SEARCH_ID = -1;
 
     /**
      * The search ID of the highlight owner.
@@ -972,12 +984,12 @@ size_t qHash(const Okular::NormalizedRect &r, size_t seed = 0);
 /**
  * Debug operator for normalized @p point.
  */
-OKULARCORE_EXPORT QDebug operator<<(QDebug str, const Okular::NormalizedPoint &point);
+OKULARCORE_EXPORT QDebug operator<<(QDebug debug, const Okular::NormalizedPoint &point);
 
 /**
  * Debug operator for normalized @p rect.
  */
-OKULARCORE_EXPORT QDebug operator<<(QDebug str, const Okular::NormalizedRect &rect);
+OKULARCORE_EXPORT QDebug operator<<(QDebug debug, const Okular::NormalizedRect &rect);
 #endif
 
 #endif
