@@ -19,6 +19,7 @@
 
 // system includes
 #include <math.h>
+#include <memory>
 
 // local includes
 #include "core/annotations.h"
@@ -102,9 +103,7 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
 
     if (!hasTilesManager) {
         /** 1 - RETRIEVE THE 'PAGE+ID' PIXMAP OR A SIMILAR 'PAGE' ONE **/
-        const QPixmap *p = page->_o_nearestPixmap(observer, dScaledWidth, dScaledHeight);
-
-        if (p != nullptr) {
+        if (const auto *p = page->_o_nearestPixmap(observer, dScaledWidth, dScaledHeight)) {
             pixmap = *p;
         }
 
@@ -125,6 +124,9 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
         }
     }
 
+    // tiles manages and this pixmap are mutually exclusive (!= is the same as XOR)
+    Q_ASSERT(hasTilesManager != !pixmap.isNull());
+
     /** 2 - FIND OUT WHAT TO PAINT (Flags + Configuration + Presence) **/
     const bool canDrawHighlights = (flags & Highlights) && !page->m_highlights.isEmpty();
     const bool canDrawTextSelection = (flags & TextSelection) && page->textSelection();
@@ -212,8 +214,9 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
     /** 3 - ENABLE BACKBUFFERING IF DIRECT IMAGE MANIPULATION IS NEEDED **/
     const bool bufferAccessibility = (flags & Accessibility) && Okular::SettingsCore::changeColors() && (Okular::SettingsCore::renderMode() != Okular::SettingsCore::EnumRenderMode::Paper);
     const bool useBackBuffer = bufferAccessibility || !bufferedHighlights.isEmpty() || !bufferedAnnotations.isEmpty() || viewPortPoint;
-    QPixmap *backPixmap = nullptr;
-    QPainter *mixedPainter = nullptr;
+    QPixmap backPixmap; // order of declarations is important: ownedPainter should be destroyed before its pixmap
+    std::unique_ptr<QPainter> ownedPainter;
+    QPainter *mixedPainter = nullptr; // Will point to either a provided destPainter or the ownedPainter
     const QRect limitsInPixmap = limits.translated(scaledCrop.topLeft());
     const QRect dLimitsInPixmap = dLimits.translated(dScaledCrop.topLeft());
 
@@ -469,11 +472,12 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
         }
 
         // 4B.5. create the back pixmap converting from the local image
-        backPixmap = new QPixmap(QPixmap::fromImage(backImage));
-        backPixmap->setDevicePixelRatio(dpr);
+        backPixmap = QPixmap::fromImage(backImage);
+        backPixmap.setDevicePixelRatio(dpr);
 
         // 4B.6. create a painter over the pixmap and set it as the active one
-        mixedPainter = new QPainter(backPixmap);
+        ownedPainter = std::make_unique<QPainter>(&backPixmap);
+        mixedPainter = ownedPainter.get();
         mixedPainter->translate(-limits.left(), -limits.top());
     }
 
@@ -555,14 +559,14 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
             Okular::StampAnnotation *stamp = static_cast<Okular::StampAnnotation *>(a);
 
             // get pixmap and alpha blend it if needed
-            const QPixmap pixmap = Okular::AnnotationUtils::loadStamp(stamp->stampIconName(), annotBoundary.size() * dpr);
-            if (!pixmap.isNull()) // should never happen but can happen on huge sizes
+            const QPixmap stampPixmap = Okular::AnnotationUtils::loadStamp(stamp->stampIconName(), annotBoundary.size() * dpr);
+            if (!stampPixmap.isNull()) // should never happen but can happen on huge sizes
             {
                 // Draw pixmap with opacity:
                 mixedPainter->save();
                 mixedPainter->setOpacity(mixedPainter->opacity() * opacity / 255.0);
 
-                mixedPainter->drawPixmap(annotRect.topLeft(), pixmap.scaled(annotBoundary.width() * dpr, annotBoundary.height() * dpr), dInnerRect.toAlignedRect());
+                mixedPainter->drawPixmap(annotRect.topLeft(), stampPixmap.scaled(annotBoundary.width() * dpr, annotBoundary.height() * dpr), dInnerRect.toAlignedRect());
 
                 mixedPainter->restore();
             }
@@ -638,9 +642,7 @@ void PagePainter::paintCroppedPageOnPainter(QPainter *destPainter,
 
     /** 7 -- BUFFERED FLOW. Copy BACKPIXMAP on DESTINATION PAINTER **/
     if (useBackBuffer) {
-        delete mixedPainter;
-        destPainter->drawPixmap(limits.left(), limits.top(), *backPixmap);
-        delete backPixmap;
+        destPainter->drawPixmap(limits.left(), limits.top(), backPixmap);
     }
 }
 
@@ -738,7 +740,7 @@ void PagePainter::invertLightness(QImage *image)
         // Hint: Lightness L = m + C / 2; L' = 255 - L = 255 - (m + C / 2) => m' = 255 - C - m
         uchar m_ = 255 - C - m;
 
-        // Add m' to color compontents
+        // Add m' to color components
         R += m_;
         G += m_;
         B += m_;
@@ -846,7 +848,7 @@ void PagePainter::invertLumaPixel(uchar &R, uchar &G, uchar &B, float Y_R, float
     // Calculate missing luma (in range 0..255), to get common component m_inv
     float m_inv = Y_inv - (Y_R * R_ + Y_G * G_ + Y_B * B_);
 
-    // Add m_inv to color compontents
+    // Add m_inv to color components
     R_ += m_inv;
     G_ += m_inv;
     B_ += m_inv;
