@@ -11,6 +11,7 @@
 #include <KComboBox>
 #include <KFontRequester>
 #include <KFormat>
+#include <KLocalization>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KMessageWidget>
@@ -46,7 +47,7 @@ PixmapPreviewSelector::PixmapPreviewSelector(QWidget *parent, PreviewPosition po
 {
     QVBoxLayout *mainlay = new QVBoxLayout(this);
     mainlay->setContentsMargins(0, 0, 0, 0);
-    QHBoxLayout *toplay = new QHBoxLayout(this);
+    QHBoxLayout *toplay = new QHBoxLayout;
     toplay->setContentsMargins(0, 0, 0, 0);
     mainlay->addLayout(toplay);
     m_comboItems = new KComboBox(this);
@@ -141,11 +142,8 @@ void PixmapPreviewSelector::iconComboChanged(const QString &icon)
         m_icon = icon;
     }
 
-    QPixmap pixmap = Okular::AnnotationUtils::loadStamp(m_icon, m_previewSize);
     const QRect cr = m_iconLabel->contentsRect();
-    if (pixmap.width() > cr.width() || pixmap.height() > cr.height()) {
-        pixmap = pixmap.scaled(cr.size(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
-    }
+    QPixmap pixmap = Okular::AnnotationUtils::loadStamp(m_icon, cr.size());
     m_iconLabel->setPixmap(pixmap);
 
     Q_EMIT iconChanged(m_icon);
@@ -155,7 +153,7 @@ void PixmapPreviewSelector::selectCustomStamp()
 {
     const QString customStampFile = QFileDialog::getOpenFileName(this, i18nc("@title:window file chooser", "Select custom stamp symbol"), QString(), i18n("*.ico *.png *.xpm *.svg *.svgz | Icon Files (*.ico *.png *.xpm *.svg *.svgz)"));
     if (!customStampFile.isEmpty()) {
-        QPixmap pixmap = Okular::AnnotationUtils::loadStamp(customStampFile, m_previewSize);
+        QPixmap pixmap = Okular::AnnotationUtils::loadStamp(customStampFile, QSize(m_previewSize, m_previewSize));
         if (pixmap.isNull()) {
             KMessageBox::error(this, xi18nc("@info", "Could not load the file <filename>%1</filename>", customStampFile), i18nc("@title:window", "Invalid file"));
         } else {
@@ -273,7 +271,7 @@ void AnnotationWidget::addOpacitySpinBox(QWidget *widget, QFormLayout *formlayou
     m_opacity = new QSpinBox(widget);
     m_opacity->setRange(0, 100);
     m_opacity->setValue((int)(m_ann->style().opacity() * 100));
-    m_opacity->setSuffix(i18nc("Suffix for the opacity level, eg '80%'", "%"));
+    KLocalization::setupSpinBoxFormatString(m_opacity, ki18nc("@label:spinbox Suffix for the opacity level, e.g. '80%'", "%v%"));
     formlayout->addRow(i18n("&Opacity:"), m_opacity);
     connect(m_opacity, QOverload<int>::of(&QSpinBox::valueChanged), this, &AnnotationWidget::dataChanged);
 }
