@@ -6,6 +6,9 @@
 
 #ifndef SNAPSHOTTAKER_H
 #define SNAPSHOTTAKER_H
+#include "config-okular.h"
+
+#if HAVE_PHONON
 
 #include <phonon/videoplayer.h>
 
@@ -32,3 +35,4 @@ private:
 };
 
 #endif
+#endif
